#![cfg(feature = "test-sync")]
use dir_odt_to_pdf::error::{ProcessError, Result};
use dir_odt_to_pdf::logging::{LogConfig, init_logging};
use log::{LevelFilter, debug, info};
use std::fs;
mod common;

#[test]
fn test_init_logging_with_file() -> Result<()> {
    // Create a temporary file for logging
    let (_temp_dir, log_path) = common::setup_test_log_file();

    // Initialize logging with Debug level
    let config = LogConfig {
        log_file: Some(log_path.clone()),
        log_level: LevelFilter::Debug,
        append_log: false,
    };

    // Initialize logging
    init_logging(config)?;
    debug!("Starting test_init_logging_with_file test");

    // Test basic logging
    info!("Testing basic file logging...");
    info!("test message");

    // Read and verify the log file
    let content = fs::read_to_string(&log_path).map_err(ProcessError::Io)?;
    println!("=== Log File Contents ===");
    println!("{}", content);
    println!("=======================");

    assert!(content.contains("test message"));
    debug!("Test completed successfully");

    Ok(())
}
